@@ -7,7 +7,7 @@ PACKAGE=orrery
 if [ ${FLAVOR} != emacs ]; then
     if test -x /usr/sbin/install-info-altdir; then
         echo remove/${PACKAGE}: removing Info links for ${FLAVOR}
-        install-info-altdir --quiet --remove --dirname=${FLAVOR} /usr/info/orrery.info.gz
+        install-info-altdir --quiet --remove --dirname=${FLAVOR} /usr/share/info/orrery.info.gz
     fi
 
     echo remove/${PACKAGE}: purging byte-compiled files for ${FLAVOR}
